.. _about:

About
=====

Questions & feedback
--------------------

*species* is maintained by Tomas Stolker (stolker@strw.leidenuniv.nl). Feel free to send an email for questions, comments, or suggestions.

Attribution
-----------

Please cite `Stolker et al. (2020) <https://ui.adsabs.harvard.edu/abs/2020A%26A...635A.182S>`_ whenever results from *species* are used in a publication. Please also make sure to give credit the relevant articles for the use of the publicly available data that *species* is using.

License
-------

*species* is distributed under the MIT License. See `LICENSE <https://github.com/tomasstolker/species/blob/main/LICENSE>`_ for the terms and conditions.

Logo
----

Are you presenting results obtained with `species` in a talk or poster? Please consider using the `logo <https://home.strw.leidenuniv.nl/~stolker/species/species_logo.zip>`_ that is available in PDF and PNG format.
